summaryrefslogtreecommitdiff
path: root/src/mongo/db/exec/fetch.cpp
diff options
context:
space:
mode:
authorMathias Stearn <mathias@10gen.com>2014-11-26 15:04:26 -0500
committerMathias Stearn <mathias@10gen.com>2014-11-26 15:15:59 -0500
commit16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8 (patch)
tree2d9f056acf8f1b9b2e943f82e315bdf019475a38 /src/mongo/db/exec/fetch.cpp
parentcb5cab88761d9aca75e064665cce89f579c69e36 (diff)
downloadmongo-16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8.tar.gz
SERVER-13679 Replace DiskLoc with RecordId outside of MMAPv1
Operations: sed -i -e 's/\<DiskLoc\>/RecordId/g' sed -i -e 's/\<DiskLocs\>/RecordIds/g' sed -i -e 's/\<minDiskLoc\>/RecordId::min()/g' sed -i -e 's/\<maxDiskLoc\>/RecordId::max()/g' sed -i -e 's/\<getDiskLoc\>/getRecordId/g'' Changes under mmap_v1 were reverted and redone by hand as needed.
Diffstat (limited to 'src/mongo/db/exec/fetch.cpp')
-rw-r--r--src/mongo/db/exec/fetch.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/exec/fetch.cpp b/src/mongo/db/exec/fetch.cpp
index bc1fd838385..f6e0dd7094b 100644
--- a/src/mongo/db/exec/fetch.cpp
+++ b/src/mongo/db/exec/fetch.cpp
@@ -85,7 +85,7 @@ namespace mongo {
return returnIfMatches(member, id, out);
}
// If we're here, we're not waiting for a DiskLoc to be fetched. Get another to-be-fetched
// result from our child.
WorkingSetID id = WorkingSet::INVALID_ID;
StageState status = _child->work(&id);
@@ -118,7 +118,7 @@ namespace mongo {
}
}
// The doc is already in memory, so go ahead and grab it. Now we have a DiskLoc
// as well as an unowned object
member->obj = _collection->docFor(_txn, member->loc);
member->keyData.clear();
@@ -164,7 +164,7 @@ namespace mongo {
_child->restoreState(opCtx);
}
- void FetchStage::invalidate(OperationContext* txn, const DiskLoc& dl, InvalidationType type) {
+ void FetchStage::invalidate(OperationContext* txn, const RecordId& dl, InvalidationType type) {
++_commonStats.invalidates;
_child->invalidate(txn, dl, type);
@@ -85,7 +85,7 @@ namespace mongo {
return returnIfMatches(member, id, out);
}
- // If we're here, we're not waiting for a DiskLoc to be fetched. Get another to-be-fetched
+ // If we're here, we're not waiting for a RecordId to be fetched. Get another to-be-fetched
// result from our child.
WorkingSetID id = WorkingSet::INVALID_ID;
@@ -118,7 +118,7 @@ namespace mongo {
}
}
- // The doc is already in memory, so go ahead and grab it. Now we have a DiskLoc
+ // The doc is already in memory, so go ahead and grab it. Now we have a RecordId
// as well as an unowned object
member->obj = _collection->docFor(_txn, member->loc);